@@ -10,6 +10,7 @@ var _         = require('lodash'),
     mkdirp    = require('mkdirp'),
     sha1      = require('sha1'),
     chalk     = require('chalk'),
+    Q         = require('q'),
     utils     = require('../utils'),
     logger    = require('../log').Logger,
     appConfig = require('../runtime/app_config');
@@ -17,6 +18,7 @@ var _         = require('lodash'),
 module.exports = function(task, context) {
   var currentTime = new Date().toISOString();
   var filesData = [];
+  var enabledDiagrams = [];
   var reportDir;
 
   var reportId = sha1(task.name + currentTime);
@@ -56,6 +58,19 @@ module.exports = function(task, context) {
     return Path.join(reportDir, datedFilename);
   };
 
+  var validation = function() {
+    var deferred = Q.defer();
+    if (_.isEmpty(filesData)) {
+      deferred.reject('Failed to create report: no available data files');
+    } else if (_.isEmpty(enabledDiagrams)) {
+      deferred.reject('Failed to create report: no diagrams enabled');
+    } else {
+      deferred.resolve();
+    }
+
+    return deferred.promise;
+  };
+
   this.addReportFileForType = function(fileType, timePeriod) {
     return addFile(fileType, timePeriod);
   };
@@ -64,18 +79,27 @@ module.exports = function(task, context) {
     return addFile(undefined, timePeriod);
   };
 
+  this.enableDiagram = function(name) {
+    enabledDiagrams.push(name);
+  };
+
   this.createManifest = function() {
-    return utils.json.objectToFile(Path.join(reportDir, 'manifest.json'), {
-      id: reportId,
-      reportName: task.reportName || task.name,
-      taskName: task.name,
-      time: currentTime,
-      dateRange: context.dateRange.toString(),
-      parameters: _.pick(context.parameters, _.pull(_.map(task.parameters, 'name'), 'dateFrom', 'dateTo')),
-      dataFiles: _.sortBy(filesData, 'timePeriod')
-    }).then(function() {
-      logger.log('Open the following link to see the results:');
-      logger.log(chalk.blue('http://localhost:' + appConfig.get('serverPort') + '/index.html?reportId=' + reportId));
+    return validation().then(function() {
+      createReportDir();
+      return utils.json.objectToFile(Path.join(reportDir, 'manifest.json'), {
+        id: reportId,
+        reportName: task.reportName || task.name,
+        taskName: task.name,
+        time: currentTime,
+        dateRange: context.dateRange.toString(),
+        parameters: _.pick(context.parameters, _.pull(_.map(task.parameters, 'name'), 'dateFrom', 'dateTo')),
+        enabledDiagrams: enabledDiagrams,
+        dataFiles: _.sortBy(filesData, 'timePeriod')
+      }).then(function() {
+        logger.log('Open the following link to see the results:');
+        logger.log(chalk.blue('http://localhost:' + appConfig.get('serverPort') + '/index.html?reportId=' + reportId));
+        return reportId;
+      });
     });
   };
 };
