@@ -15,6 +15,7 @@ var _          = require('lodash'),
 
 module.exports = function(taskDef, context, helpers) {
   var vcsAdapter = vcsSupport.adapter(context.repository);
+  var vcsLogTransformer = vcsSupport.logStreamTransformer(context.repository, context.developersInfo);
 
   var createLogFiles = function(fileType, adapterMethod) {
     var logItems = _.map(context.timePeriods, function(period) {
@@ -31,12 +32,12 @@ module.exports = function(taskDef, context, helpers) {
     });
   };
 
-  var normaliseLogFiles = function(logItems, transformer) {
+  var normaliseLogFiles = function(logItems) {
     var transformLogItems = _.map(logItems, function(item) {
       return { source: item.file, target: helpers.files.vcsNormalisedLog(item.timePeriod) };
     });
     return pp.taskExecutor().processAll(utils.arrays.arrayToFnFactory(transformLogItems, function(item) {
-      return transformer
+      return vcsLogTransformer
         .normaliseLogStream(fs.createReadStream(item.source))
         .pipe(fs.createWriteStream(item.target));
     })).then(function() {
@@ -48,7 +49,7 @@ module.exports = function(taskDef, context, helpers) {
 
   taskDef.addTask('vcs-log-dump', taskInfo, function() {
     return createLogFiles('vcslog', 'logStream').then(function(logItems) {
-      return normaliseLogFiles(logItems, vcsSupport.logStreamTransformer(context.repository, context.developerInfo));
+      return normaliseLogFiles(logItems);
     });
   });
 
